@@ -1,20 +1,21 @@
 /* mpf_sub -- Subtract two floats.
 
-Copyright (C) 1993, 1994, 1995, 1996, 1999 Free Software Foundation, Inc.
+Copyright (C) 1993, 1994, 1995, 1996, 1999, 2000 Free Software Foundation,
+Inc.
 
 This file is part of the GNU MP Library.
 
 The GNU MP Library is free software; you can redistribute it and/or modify
-it under the terms of the GNU Library General Public License as published by
-the Free Software Foundation; either version 2 of the License, or (at your
+it under the terms of the GNU Lesser General Public License as published by
+the Free Software Foundation; either version 2.1 of the License, or (at your
 option) any later version.
 
 The GNU MP Library is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
-You should have received a copy of the GNU Library General Public License
+You should have received a copy of the GNU Lesser General Public License
 along with the GNU MP Library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 MA 02111-1307, USA. */
@@ -141,8 +142,7 @@ mpf_sub (r, u, v)
 		 wouldn't have exited unless up[usize - 1] and vp[vsize - 1]
 		 were non-equal, this if-statement catches all cases where U
 		 is smaller than V.  */
-	      { mp_srcptr tp = up; up = vp; vp = tp; }
-	      { mp_size_t tsize = usize; usize = vsize; vsize = tsize; }
+	      MPN_SRCPTR_SWAP (up,usize, vp,vsize);
 	      negate ^= 1;
 	      /* negating ediff not necessary since it is 0.  */
 	    }
